@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ietf_constants.h,v 1.4.2.1 2004/07/22 18:24:39 ken Exp $
+ * RCSID $Id: ietf_constants.h,v 1.9 2004/12/09 18:17:30 mcr Exp $
  */
 
 /* Group parameters from draft-ietf-ike-01.txt section 6 */
@@ -193,6 +193,7 @@
 #define SHA1_DIGEST_SIZE	BYTES_FOR_BITS(160)	/* ought to be supplied by sha1.h */
 
 #define DES_CBC_BLOCK_SIZE	BYTES_FOR_BITS(64)
+#define AES_CBC_BLOCK_SIZE      BYTES_FOR_BITS(128)
 
 #define DSS_QBITS	160	/* bits in DSS's "q" (FIPS 186-1) */
 
@@ -604,7 +605,7 @@ extern enum_names oakley_auth_names;
 #define OAKLEY_ELGAMAL_ENC         6
 #define OAKLEY_ELGAMAL_ENC_REV     7
 
-#define OAKLEY_AUTH_ROOF           8	/* roof on auth values THAT WE SUPPORT */
+#define OAKLEY_AUTH_ROOF           8  /*roof on auth values THAT WE SUPPORT */
 
 #define HybridInitRSA                                     64221
 #define HybridRespRSA                                     64222
@@ -623,6 +624,8 @@ extern enum_names oakley_auth_names;
 #define XAUTHInitRSARevisedEncryption                     65009
 #define XAUTHRespRSARevisedEncryption                     65010
 
+/* typedef to make our life easier */
+typedef u_int16_t oakley_auth_t;
 
 
 /* Oakley Group Description attribute
@@ -630,6 +633,7 @@ extern enum_names oakley_auth_names;
  */
 extern enum_names oakley_group_names;
 
+typedef u_int16_t oakley_group_t;
 #define OAKLEY_GROUP_MODP768       1
 #define OAKLEY_GROUP_MODP1024      2
 #define OAKLEY_GROUP_GP155         3
@@ -735,7 +739,6 @@ enum pubkey_alg
 #define RSA_MIN_OCTETS	BYTES_FOR_BITS(512)
 #define RSA_MIN_OCTETS_UGH	"RSA modulus too small for security: less than 512 bits"
 
-
 #define RSA_MAX_OCTETS	BYTES_FOR_BITS(8192)
 #define RSA_MAX_OCTETS_UGH	"RSA modulus too large: more than 8192 bits"
 
