@@ -13,7 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: ipsec_policy.h,v 1.5 2004/06/17 04:23:33 mcr Exp $
+ * RCSID $Id: ipsec_policy.h,v 1.6 2004/12/09 18:16:53 mcr Exp $
  */
 #define	_IPSEC_POLICY_H 	/* seen it, no need to see it again */
 
@@ -101,7 +101,7 @@ enum ipsec_cipher_algo {
   ESP_DES_IV32=9,
   ESP_RC4=10,
   ESP_NULL=11,
-  ESP_AES=12,
+  ESP_AES=12,         /* 128 bit AES */
 };
 
 /* IPCOMP transform values
