@@ -1,4 +1,4 @@
-char radij_c_version[] = "RCSID $Id: radij.c,v 1.46 2004/04/06 02:49:26 mcr Exp $";
+char radij_c_version[] = "RCSID $Id: radij.c,v 1.47 2004/07/10 19:11:18 mcr Exp $";
 
 /*
  * This file is defived from ${SRC}/sys/net/radix.c of BSD 4.4lite
@@ -777,7 +777,7 @@ rj_walktree(h, f, w)
 	while (rn->rj_b >= 0)
 		rn = rn->rj_l;
 	for (;;) {
-#ifdef CONFIG_IPSEC_DEBUG
+#ifdef CONFIG_KLIPS_DEBUG
 		if(debug_radij) {
 			printk("klips_debug:rj_walktree: "
 			       "for: rn=0p%p rj_b=%d rj_flags=%x",
@@ -792,7 +792,7 @@ rj_walktree(h, f, w)
 				       (u_int)ntohl(((struct sockaddr_encap *)rn->rj_key)->sen_ip_dst.s_addr))
 				;
 		}
-#endif /* CONFIG_IPSEC_DEBUG */
+#endif /* CONFIG_KLIPS_DEBUG */
 		base = rn;
 		/* If at right child go back up, otherwise, go right */
 		while (rn->rj_p->rj_r == rn && (rn->rj_flags & RJF_ROOT) == 0)
@@ -801,7 +801,7 @@ rj_walktree(h, f, w)
 		for (rn = rn->rj_p->rj_r; rn->rj_b >= 0;)
 			rn = rn->rj_l;
 		next = rn;
-#ifdef CONFIG_IPSEC_DEBUG
+#ifdef CONFIG_KLIPS_DEBUG
 		if(debug_radij) {
 			printk("klips_debug:rj_walktree: "
 			       "processing leaves, rn=0p%p rj_b=%d rj_flags=%x",
@@ -816,11 +816,11 @@ rj_walktree(h, f, w)
 				       (u_int)ntohl(((struct sockaddr_encap *)rn->rj_key)->sen_ip_dst.s_addr))
 				;
 		}
-#endif /* CONFIG_IPSEC_DEBUG */
+#endif /* CONFIG_KLIPS_DEBUG */
 		/* Process leaves */
 		while ((rn = base)) {
 			base = rn->rj_dupedkey;
-#ifdef CONFIG_IPSEC_DEBUG
+#ifdef CONFIG_KLIPS_DEBUG
 			if(debug_radij) {
 				printk("klips_debug:rj_walktree: "
 				       "while: base=0p%p rn=0p%p rj_b=%d rj_flags=%x",
@@ -836,7 +836,7 @@ rj_walktree(h, f, w)
 					       (u_int)ntohl(((struct sockaddr_encap *)rn->rj_key)->sen_ip_dst.s_addr))
 					;
 			}
-#endif /* CONFIG_IPSEC_DEBUG */
+#endif /* CONFIG_KLIPS_DEBUG */
 			if (!(rn->rj_flags & RJF_ROOT) && (error = (*f)(rn, w)))
 				return (-error);
 		}
@@ -1005,6 +1005,9 @@ radijcleanup(void)
 
 /*
  * $Log: radij.c,v $
+ * Revision 1.47  2004/07/10 19:11:18  mcr
+ * 	CONFIG_IPSEC -> CONFIG_KLIPS.
+ *
  * Revision 1.46  2004/04/06 02:49:26  mcr
  * 	pullup of algo code from alg-branch.
  *
