@@ -14,7 +14,7 @@
  * for more details.
  */
 
-char eroute_c_version[] = "RCSID $Id: eroute.c,v 1.60 2004/04/06 02:58:43 mcr Exp $";
+char eroute_c_version[] = "RCSID $Id: eroute.c,v 1.61 2004/12/10 12:38:29 paul Exp $";
 
 
 #include <sys/types.h>
@@ -454,7 +454,7 @@ main(int argc, char **argv)
         if(argcount == 1) {
                 struct stat sts;
                 if ( ((stat ("/proc/net/pfkey", &sts)) == 0) )  {
-                         fprintf(stderr, "%s: 2.6 native pf_key does not support eroute table.\n",program_name);
+                         fprintf(stderr, "%s: NETKEY does not support eroute table.\n",program_name);
 
                         exit(1);
                 }
@@ -904,6 +904,9 @@ main(int argc, char **argv)
 }
 /*
  * $Log: eroute.c,v $
+ * Revision 1.61  2004/12/10 12:38:29  paul
+ * Renamed the stack names consistently to KLIPS and NETKEY
+ *
  * Revision 1.60  2004/04/06 02:58:43  mcr
  * 	freeswan->openswan changes.
  *
