@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ikeping.c,v 1.6 2004/04/18 03:05:10 mcr Exp $
+ * RCSID $Id: ikeping.c,v 1.7 2004/10/17 23:58:59 mcr Exp $
  */
 
 #include <stdio.h>
@@ -34,7 +34,7 @@
 #include <openswan.h>
 
 #include "constants.h"
-#include "../pluto/packet.h"
+#include "packet.h"
 
 #ifndef ISAKMP_XCHG_ECHOREQUEST
 #define ISAKMP_XCHG_ECHOREQUEST 30      /* Echo Request */
