@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: connections.h,v 1.95 2004/06/27 20:46:15 mcr Exp $
+ * RCSID $Id: connections.h,v 1.98 2004/10/25 01:41:33 mcr Exp $
  */
 
 /* There are two kinds of connections:
@@ -187,11 +187,11 @@ struct connection {
     unsigned long sa_keying_tries;
 
     /* RFC 3706 DPD */
-    time_t dpd_delay;
-    time_t dpd_timeout;
-    int dpd_action;
+    time_t          dpd_delay;
+    time_t          dpd_timeout;
+    enum dpd_action dpd_action;
 
-    bool forceencaps;
+    bool               forceencaps;         /* always use NAT-T encap */
 
     char              *log_file_name;       /* name of log file */
     FILE              *log_file;            /* possibly open FILE */
@@ -257,7 +257,9 @@ extern size_t format_end(char *buf, size_t buf_len
 
 struct whack_message;	/* forward declaration of tag whack_msg */
 extern void add_connection(const struct whack_message *wm);
-extern void initiate_connection(const char *name, int whackfd);
+extern void initiate_connection(const char *name
+				, int whackfd
+				, enum crypto_importance importance);
 extern void initiate_opportunistic(const ip_address *our_client
     , const ip_address *peer_client, int transport_proto, bool held, int whackfd, err_t why);
 extern void terminate_connection(const char *nm);
@@ -289,7 +291,7 @@ extern struct connection
     *find_host_connection(const ip_address *me, u_int16_t my_port
 	, const ip_address *him, u_int16_t his_port),
     *refine_host_connection(const struct state *st, const struct id *id
-	, bool initiator),
+	, bool initiator, bool aggrmode),
     *find_client_connection(struct connection *c
 			    , const ip_subnet *our_net
 			    , const ip_subnet *peer_net
