@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: crypto.c,v 1.29 2004/04/18 03:06:46 mcr Exp $
+ * RCSID $Id: crypto.c,v 1.33 2004/11/25 18:18:58 mcr Exp $
  */
 
 #include <stdio.h>
@@ -40,7 +40,7 @@
 
 
 static MP_INT
-#if 0	/* modp768 not sufficiently strong */
+#if defined(USE_VERYWEAK_DH1) 	/* modp768 not sufficiently strong */
     modp768_modulus,
 #endif
     modp1024_modulus,
@@ -74,9 +74,9 @@ static struct hash_desc crypto_hasher_md5 =
 		 algo_next: NULL, },
 	hash_ctx_size: sizeof(MD5_CTX),
 	hash_digest_len: MD5_DIGEST_SIZE,
-	hash_init: (void (*)(void *)) MD5Init,
-	hash_update: (void (*)(void *, const u_int8_t *, size_t)) MD5Update,
-	hash_final: (void (*)(u_char *, void *)) MD5Final,
+	hash_init: (void (*)(void *)) osMD5Init,
+	hash_update: (void (*)(void *, const u_int8_t *, size_t)) osMD5Update,
+	hash_final: (void (*)(u_char *, void *)) osMD5Final,
 };
 static struct hash_desc crypto_hasher_sha1 =
 { 	
@@ -94,7 +94,7 @@ void
 init_crypto(void)
 {
     if (mpz_init_set_str(&groupgenerator, MODP_GENERATOR, 10) != 0
-#if 0	/* modp768 not sufficiently strong */
+#if defined(USE_VERYWEAK_DH1)	                        /* modp768 not sufficiently strong */
     || mpz_init_set_str(&modp768_modulus, MODP768_MODULUS, 16) != 0
 #endif
     || mpz_init_set_str(&modp1024_modulus, MODP1024_MODULUS, 16) != 0
@@ -123,8 +123,8 @@ init_crypto(void)
 
 const struct oakley_group_desc unset_group = {0, NULL, 0};	/* magic signifier */
 
-const struct oakley_group_desc oakley_group[OAKLEY_GROUP_SIZE] = {
-#if 0	/* modp768 not sufficiently strong */
+const struct oakley_group_desc oakley_group[] = {
+#if defined(USE_VERYWEAK_DH1)    	/* modp768 not sufficiently strong */
     { OAKLEY_GROUP_MODP768, &modp768_modulus, BYTES_FOR_BITS(768) },
 #endif
     { OAKLEY_GROUP_MODP1024, &modp1024_modulus, BYTES_FOR_BITS(1024) },
@@ -136,6 +136,8 @@ const struct oakley_group_desc oakley_group[OAKLEY_GROUP_SIZE] = {
     { OAKLEY_GROUP_MODP8192, &modp8192_modulus, BYTES_FOR_BITS(8192) },
 };
 
+const unsigned int oakley_group_size = elemsof(oakley_group);
+
 const struct oakley_group_desc *
 lookup_group(u_int16_t group)
 {
@@ -175,19 +177,22 @@ do_des(bool enc, void *buf, size_t buf_len, struct state *st)
  * See RFC 2409 "IKE" Appendix B
  */
 static void
-do_3des(u_int8_t *buf, size_t buf_len, u_int8_t *key, size_t key_size, u_int8_t *iv, bool enc)
+do_3des(u_int8_t *buf, size_t buf_len
+	, u_int8_t *key, size_t key_size, u_int8_t *iv, bool enc)
 {
     des_key_schedule ks[3];
 
-    passert (!key_size || (key_size==(DES_CBC_BLOCK_SIZE * 3)))
+    passert(key != NULL);
+    passert(key_size==(DES_CBC_BLOCK_SIZE * 3));
     (void) des_set_key((des_cblock *)key + 0, ks[0]);
     (void) des_set_key((des_cblock *)key + 1, ks[1]);
     (void) des_set_key((des_cblock *)key + 2, ks[2]);
 
     des_ede3_cbc_encrypt((des_cblock *)buf, (des_cblock *)buf, buf_len,
-	ks[0], ks[1], ks[2],
-	(des_cblock *)iv, enc);
+			 ks[0], ks[1], ks[2],
+			 (des_cblock *)iv, enc);
 }
+
 /* hash and prf routines */
 /*========================================================== 
  *
@@ -203,18 +208,29 @@ struct encrypt_desc *crypto_get_encrypter(int alg)
 {
 	return (struct encrypt_desc *) ike_alg_find(IKE_ALG_ENCRYPT, alg, 0);
 }
+
 void 
-crypto_cbc_encrypt(const struct encrypt_desc *e, bool enc, u_int8_t *buf, size_t size, struct state *st)
+crypto_cbc_encrypt(const struct encrypt_desc *e, bool enc
+		   , u_int8_t *buf, size_t size, struct state *st)
 {
     passert(st->st_new_iv_len >= e->enc_blocksize);
     st->st_new_iv_len = e->enc_blocksize;	/* truncate */
 
-    e->do_crypt(buf, size, st->st_enc_key.ptr, st->st_enc_key.len, st->st_new_iv, enc);
+#if 0
+    DBG(DBG_CRYPT
+	, DBG_log("encrypting buf=%p size=%d keyptr: %p keysize: %d, iv: %p enc: %d"
+		  , buf, size, st->st_enc_key.ptr
+		  , st->st_enc_key.len, st->st_new_iv, enc));
+#endif
+
+    e->do_crypt(buf, size, st->st_enc_key.ptr
+		, st->st_enc_key.len, st->st_new_iv, enc);
     /*
-    e->set_key(&ctx, st->st_enc_key.ptr, st->st_enc_key.len);
-    e->cbc_crypt(&ctx, buf, size, st->st_new_iv, enc);
+      e->set_key(&ctx, st->st_enc_key.ptr, st->st_enc_key.len);
+      e->cbc_crypt(&ctx, buf, size, st->st_new_iv, enc);
     */
 }
+
 /* HMAC package
  * rfc2104.txt specifies how HMAC works.
  */
