@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: demux.c,v 1.169 2004/06/20 12:47:41 ken Exp $
+ * RCSID $Id: demux.c,v 1.187.2.1 2004/12/31 03:42:48 ken Exp $
  */
 
 /* Ordering Constraints on Payloads
@@ -208,7 +208,6 @@ struct state_microcode {
 #define SMF_DS_AUTH	(LELEM(OAKLEY_DSS_SIG) | LELEM(OAKLEY_RSA_SIG))
 #define SMF_PKE_AUTH	(LELEM(OAKLEY_RSA_ENC) | LELEM(OAKLEY_ELGAMAL_ENC))
 #define SMF_RPKE_AUTH	(LELEM(OAKLEY_RSA_ENC_REV) | LELEM(OAKLEY_ELGAMAL_ENC_REV))
-
 /* misc flags */
 
 #define SMF_INITIATOR	LELEM(OAKLEY_AUTH_ROOF + 0)
@@ -225,6 +224,10 @@ struct state_microcode {
 /* this state completes P1, so any pending P2 negotiations should start */
 #define SMF_RELEASE_PENDING_P2	LELEM(OAKLEY_AUTH_ROOF + 6)
 
+/* if we have canoncalized the authentication from XAUTH mode */
+#define SMF_XAUTH_AUTH  LELEM(OAKLEY_AUTH_ROOF + 7)
+
+
 /* end of flags */
 
 
@@ -392,6 +395,69 @@ static const struct state_microcode state_microcode_table[] = {
     , LEMPTY, LEMPTY
     , PT(NONE), EVENT_NULL, unexpected },
 
+    /***** Phase 1 Aggressive Mode *****/
+
+    /* No state for aggr_outI1: -->HDR, SA, KE, Ni, IDii */
+
+    /* STATE_AGGR_R0:
+     * SMF_PSK_AUTH: HDR, SA, KE, Ni, IDii
+     *                -->  HDR, SA, KE, Nr, IDir, HASH_R
+     * SMF_DS_AUTH:  HDR, KE, Nr, SIG --> HDR*, IDi1, HASH_I
+     */
+    { STATE_AGGR_R0, STATE_AGGR_R1,
+      SMF_PSK_AUTH| SMF_REPLY,
+      P(SA) | P(KE) | P(NONCE) | P(ID), P(VID), PT(NONE),
+      EVENT_RETRANSMIT, aggr_inI1_outR1_psk },
+
+    { STATE_AGGR_R0, STATE_AGGR_R1,
+      SMF_DS_AUTH | SMF_REPLY,
+      P(SA) | P(KE) | P(NONCE) | P(ID), P(VID), PT(NONE),
+      EVENT_RETRANSMIT, aggr_inI1_outR1_rsasig },
+
+    /* STATE_AGGR_I1:
+     * SMF_PSK_AUTH: HDR, SA, KE, Nr, IDir, HASH_R
+     *                                 --> HDR*, HASH_I
+     * SMF_DS_AUTH: HDR, SA, KE, Nr, IDir, SIG_R
+     *                                 --> HDR*, SIG_I
+     */
+    { STATE_AGGR_I1, STATE_AGGR_I2,
+      SMF_PSK_AUTH | SMF_INITIATOR | SMF_OUTPUT_ENCRYPTED | SMF_REPLY | SMF_RELEASE_PENDING_P2,
+      P(SA) | P(KE) | P(NONCE) | P(ID) | P(HASH), P(VID) | P(NATD_RFC) , PT(NONE),
+      EVENT_SA_REPLACE, aggr_inR1_outI2 },
+
+    { STATE_AGGR_I1, STATE_AGGR_I2,
+      SMF_DS_AUTH | SMF_INITIATOR | SMF_OUTPUT_ENCRYPTED | SMF_REPLY | SMF_RELEASE_PENDING_P2,
+      P(SA) | P(KE) | P(NONCE) | P(ID) | P(SIG), P(VID) | P(NATD_RFC) , PT(NONE),
+      EVENT_SA_REPLACE, aggr_inR1_outI2 },
+
+    /* STATE_AGGR_R1:
+     * SMF_PSK_AUTH: HDR*, HASH_I --> done
+     * SMF_DS_AUTH: HDR*, SIG_I   --> done
+     */
+    { STATE_AGGR_R1, STATE_AGGR_R2,
+      SMF_PSK_AUTH | SMF_FIRST_ENCRYPTED_INPUT
+      | SMF_ENCRYPTED | SMF_RELEASE_PENDING_P2,
+      P(HASH), P(VID) | P(NATD_RFC), PT(NONE),
+      EVENT_SA_REPLACE, aggr_inI2 },
+
+    /* STATE_AGGR_R1: HDR*, HASH_I --> done */
+    { STATE_AGGR_R1, STATE_AGGR_R2,
+      SMF_DS_AUTH | SMF_FIRST_ENCRYPTED_INPUT
+      | SMF_ENCRYPTED | SMF_RELEASE_PENDING_P2,
+      P(SIG), P(VID) | P(NATD_RFC), PT(NONE),
+      EVENT_SA_REPLACE, aggr_inI2 },
+
+    /* STATE_AGGR_I2: can only get here due to packet loss */
+    { STATE_AGGR_I2, STATE_UNDEFINED,
+      SMF_ALL_AUTH | SMF_INITIATOR | SMF_RETRANSMIT_ON_DUPLICATE,
+      LEMPTY, LEMPTY, PT(NONE), EVENT_NULL, unexpected },
+
+    /* STATE_AGGR_R2: can only get here due to packet loss */
+    { STATE_AGGR_R2, STATE_UNDEFINED,
+      SMF_ALL_AUTH,
+      LEMPTY, LEMPTY, PT(NONE), EVENT_NULL, unexpected },
+
+
     /***** Phase 2 Quick Mode *****/
 
     /* No state for quick_outI1:
@@ -474,6 +540,19 @@ static const struct state_microcode state_microcode_table[] = {
     , SMF_ALL_AUTH | SMF_ENCRYPTED 
     , P(ATTR) | P(HASH), P(VID), PT(NONE)
     , EVENT_SA_REPLACE, xauth_inR1 },
+
+#if 0
+    /* for situation where there is XAUTH + ModeCFG */
+    { STATE_XAUTH_R2, STATE_XAUTH_R3
+    , SMF_ALL_AUTH | SMF_ENCRYPTED 
+    , P(ATTR) | P(HASH), P(VID), PT(NONE)
+    , EVENT_SA_REPLACE, xauth_inR2 },
+
+    { STATE_XAUTH_R3, STATE_MAIN_R3
+    , SMF_ALL_AUTH | SMF_ENCRYPTED 
+    , P(ATTR) | P(HASH), P(VID), PT(NONE)
+    , EVENT_SA_REPLACE, xauth_inR3 },
+#endif
 #endif
 
 #ifdef MODECFG
@@ -500,6 +579,11 @@ static const struct state_microcode state_microcode_table[] = {
     , SMF_ALL_AUTH | SMF_ENCRYPTED
     , LEMPTY, LEMPTY, PT(NONE)
     , EVENT_NULL, unexpected },
+
+    { STATE_MODE_CFG_I1, STATE_MAIN_I4
+    , SMF_ALL_AUTH | SMF_ENCRYPTED | SMF_RELEASE_PENDING_P2
+    , P(ATTR) | P(HASH), P(VID), PT(HASH)
+    , EVENT_SA_REPLACE, modecfg_inR1 },
 #endif
 
 #ifdef XAUTH
@@ -925,7 +1009,7 @@ unexpected(struct msg_digest *md)
 }
 
 static stf_status
-informational(struct msg_digest *md UNUSED)
+informational(struct msg_digest *md)
 {
     struct payload_digest *const n_pld = md->chain[ISAKMP_NEXT_N];
 
@@ -936,15 +1020,40 @@ informational(struct msg_digest *md UNUSED)
         struct isakmp_notification *const n = &n_pld->payload.notification;
         int disp_len;
         char disp_buf[200];
+	struct state *st = md->st;            /* may be NULL */
 
         /* Switch on Notification Type (enum) */
+	/* note that we can get notification payloads unencrypted
+	 * once we are at least in R3/I4. 
+	 * and that the handler is expected to treat them suspiciously.
+	 */
         switch (n->isan_type)
         {
         case R_U_THERE:
-            return dpd_inI_outR(md->st, n, n_pbs);
+            return dpd_inI_outR(st, n, n_pbs);
 
         case R_U_THERE_ACK:
-            return dpd_inR(md->st, n, n_pbs);
+            return dpd_inR(st, n, n_pbs);
+
+	case PAYLOAD_MALFORMED:
+	    if(st) {
+		st->hidden_variables.st_malformed_received++;
+
+		openswan_log("received %u malformed payload notifies"
+			     , st->hidden_variables.st_malformed_received);
+
+		if(st->hidden_variables.st_malformed_sent > MAXIMUM_MALFORMED_NOTIFY/2
+		   && ((st->hidden_variables.st_malformed_sent
+			+ st->hidden_variables.st_malformed_received)
+		       > MAXIMUM_MALFORMED_NOTIFY)) {
+		    openswan_log("too many malformed payloads (we sent %u and received %u"
+				 , st->hidden_variables.st_malformed_sent
+				 , st->hidden_variables.st_malformed_received);
+		    delete_state(st);
+		}
+	    }
+	    return STF_IGNORE;
+
         default:
             if (pbs_left(n_pbs) >= sizeof(disp_buf)-1)
                 disp_len = sizeof(disp_buf)-1;
@@ -980,7 +1089,7 @@ free_md_pool(void)
     }
 }
 
-static struct msg_digest *
+struct msg_digest *
 alloc_md(void)
 {
     struct msg_digest *md = md_pool;
@@ -1009,9 +1118,14 @@ alloc_md(void)
     return md;
 }
 
+struct state *looking_for_state = NULL;
+struct msg_digest *looking_for_md = NULL;
+
 void
 release_md(struct msg_digest *md)
 {
+    passert(looking_for_md == NULL || md != looking_for_md);
+    passert(looking_for_state == NULL || md->st != looking_for_state);
     freeanychunk(md->raw_packet);
     pfreeany(md->packet_pbs.start);
     md->packet_pbs.start = NULL;
@@ -1290,15 +1404,14 @@ process_packet(struct msg_digest **mdp)
 #ifdef NOTYET
     case ISAKMP_XCHG_NONE:
     case ISAKMP_XCHG_BASE:
+    case ISAKMP_XCHG_AO:
 #endif
 
-    case ISAKMP_XCHG_AO:
     case ISAKMP_XCHG_AGGR:
-
     case ISAKMP_XCHG_IDPROT:	/* part of a Main Mode exchange */
 	if (md->hdr.isa_msgid != MAINMODE_MSGID)
 	{
-	    openswan_log("Message ID was 0x%08lx but should be zero in Main Mode",
+	    openswan_log("Message ID was 0x%08lx but should be zero in phase 1",
 		(unsigned long) md->hdr.isa_msgid);
 	    SEND_NOTIFICATION(INVALID_MESSAGE_ID);
 	    return;
@@ -1306,7 +1419,7 @@ process_packet(struct msg_digest **mdp)
 
 	if (is_zero_cookie(md->hdr.isa_icookie))
 	{
-	    openswan_log("Initiator Cookie must not be zero in Main Mode message");
+	    openswan_log("Initiator Cookie must not be zero in phase 1 message");
 	    SEND_NOTIFICATION(INVALID_COOKIE);
 	    return;
 	}
@@ -1318,14 +1431,15 @@ process_packet(struct msg_digest **mdp)
 	     */
 	    if (md->hdr.isa_flags & ISAKMP_FLAG_ENCRYPTION)
 	    {
-		openswan_log("initial Main Mode message is invalid:"
+		openswan_log("initial phase 1 message is invalid:"
 		    " its Encrypted Flag is on");
 		SEND_NOTIFICATION(INVALID_FLAGS);
 		return;
 	    }
 
 	    /* don't build a state until the message looks tasty */
-	    from_state = STATE_MAIN_R0;
+	    from_state = (md->hdr.isa_xchg == ISAKMP_XCHG_IDPROT
+				? STATE_MAIN_R0 : STATE_AGGR_R0);
 	}
 	else
 	{
@@ -1344,7 +1458,7 @@ process_packet(struct msg_digest **mdp)
 
 		if (st == NULL)
 		{
-		    openswan_log("Main Mode message is part of an unknown exchange");
+		    openswan_log("phase 1 message is part of an unknown exchange");
 		    /* XXX Could send notification back */
 		    return;
 		}
@@ -1402,7 +1516,8 @@ process_packet(struct msg_digest **mdp)
 	}
 	else
 	{
-	    if (st != NULL && IS_ISAKMP_ENCRYPTED(st->st_state))
+	    if (st != NULL &&
+		(IS_ISAKMP_AUTHENTICATED(st->st_state)))
 	    {
 		loglog(RC_LOG_SERIOUS, "Informational Exchange message"
 		    " must be encrypted");
@@ -1575,7 +1690,7 @@ process_packet(struct msg_digest **mdp)
 
 	    /*
 	     * okay, now we have to figure out if we are receiving a bogus
-	     * new message in an oustanding XAUTH server conservation
+	     * new message in an oustanding XAUTH server conversation
 	     * (i.e. a reply to our challenge)
 	     * (this occurs with some broken other implementations).
 	     *
@@ -1618,6 +1733,11 @@ process_packet(struct msg_digest **mdp)
 	    {
 		from_state = STATE_MODE_CFG_R0;
 	    }
+	    else if(st->st_connection->spd.this.modecfg_client
+		    && IS_PHASE1(st->st_state))
+	    {
+		from_state = STATE_MODE_CFG_R1;
+	    }
 	    else {
 		/* XXX check if we are being a mode config server here */
 		openswan_log("received MODECFG message when in state %s, and we aren't xauth client"
@@ -1681,10 +1801,11 @@ process_packet(struct msg_digest **mdp)
 
     if (st != NULL)
     {
-	while (!LHAS(smc->flags, st->st_oakley.auth))
+      oakley_auth_t baseauth = xauth_calcbaseauth(st->st_oakley.auth);
+      while (!LHAS(smc->flags, baseauth))
 	{
-	    smc++;
-	    passert(smc->state == from_state);
+	  smc++;
+	  passert(smc->state == from_state);
 	}
     }
 
@@ -2055,10 +2176,14 @@ process_packet(struct msg_digest **mdp)
 	for (p = md->chain[ISAKMP_NEXT_N]; p != NULL; p = p->next)
 	{
                 if(p->payload.notification.isan_type != R_U_THERE
-                && p->payload.notification.isan_type != R_U_THERE_ACK)
+		   && p->payload.notification.isan_type != R_U_THERE_ACK
+		   && p->payload.notification.isan_type != PAYLOAD_MALFORMED) {
 
-	    loglog(RC_LOG_SERIOUS, "ignoring informational payload, type %s"
-		, enum_show(&ipsec_notification_names, p->payload.notification.isan_type));
+		    loglog(RC_LOG_SERIOUS
+			   , "ignoring informational payload, type %s"
+			   , enum_show(&ipsec_notification_names
+				       , p->payload.notification.isan_type));
+		}
 	    DBG_cond_dump(DBG_PARSING, "info:", p->pbs.cur, pbs_left(&p->pbs));
 	}
 
@@ -2113,9 +2238,21 @@ complete_state_transition(struct msg_digest **mdp, stf_status result)
     cur_state = st = md->st;	/* might have changed */
 
     /* If state has DPD support, import it */
-    if( st && md->dpd)
-	st->st_dpd = md->dpd;
+    if( st && md->dpd) {
+	DBG(DBG_DPD, DBG_log("peer supports dpd"));
+	st->hidden_variables.st_dpd = md->dpd;
 
+	if(st->st_connection->dpd_delay && st->st_connection->dpd_timeout) {
+	    /* Set local policy for DPD to be on */
+	    st->hidden_variables.st_dpd_local = 1;
+	    DBG(DBG_DPD, DBG_log("enabling sending dpd"));
+	}
+    }
+
+    /* advance the state */
+    DBG(DBG_CONTROL
+	, DBG_log("complete state transition with %s"
+		  , enum_name(&stfstatus_name, result)));
 
     switch (result)
     {
@@ -2130,7 +2267,7 @@ complete_state_transition(struct msg_digest **mdp, stf_status result)
 	case STF_OK:
 	    /* advance the state */
 	    openswan_log("transition from state %s to state %s"
-                 , enum_name(&state_names, st->st_state)
+                 , enum_name(&state_names, from_state)
                  , enum_name(&state_names, smc->next_state));
 	    
 	    st->st_state = smc->next_state;
@@ -2163,6 +2300,7 @@ complete_state_transition(struct msg_digest **mdp, stf_status result)
 	    /* if requested, send the new reply packet */
 	    if (smc->flags & SMF_REPLY)
 	    {
+		DBG(DBG_CONTROL, DBG_log("sending reply packet"));
 		close_output_pbs(&md->reply);   /* good form, but actually a no-op */
 
 		clonetochunk(st->st_tpacket, md->reply.start
@@ -2302,9 +2440,11 @@ complete_state_transition(struct msg_digest **mdp, stf_status result)
 
 	    /* tell whack and log of progress */
 	    {
-		const char *story = state_story[st->st_state - STATE_MAIN_R0];
+		const char *story = enum_name(&state_stories, st->st_state);
 		enum rc_type w = RC_NEW_STATE + st->st_state;
 		char sadetails[128];
+
+		passert(st->st_state < STATE_IKE_ROOF);
 		
 		sadetails[0]='\0';
 
@@ -2318,9 +2458,17 @@ complete_state_transition(struct msg_digest **mdp, stf_status result)
 
 		    if(st->st_esp.present)
 		    {
+			const char *natinfo="";
+
+			if((st->st_connection->spd.that.host_port != IKE_UDP_PORT
+			    && st->st_connection->spd.that.host_port != 0)
+			   || st->st_connection->forceencaps) {
+			    natinfo="/NAT";
+			}
 			snprintf(b, sizeof(sadetails)-(b-sadetails)-1
-				 , "%sESP=>0x%08x <0x%08x"
+				 , "%sESP%s=>0x%08x <0x%08x"
 				 , ini
+				 , natinfo
 				 , ntohl(st->st_esp.attrs.spi)
 				 , ntohl(st->st_esp.our_spi));
 			ini = " ";
@@ -2371,7 +2519,7 @@ complete_state_transition(struct msg_digest **mdp, stf_status result)
 		    /* advance b to end of string */
 		    b = b + strlen(b);
 		    
-		    if(st->st_dpd_local)
+		    if(st->hidden_variables.st_dpd_local)
 		    {
 			snprintf(b, sizeof(sadetails)-(b-sadetails)-1
 				 , "%sDPD"
@@ -2398,6 +2546,20 @@ complete_state_transition(struct msg_digest **mdp, stf_status result)
 		    , story, sadetails);
 	    }
 
+	    /*
+	     * make sure that a DPD event gets created for a new phase 1
+	     * SA.
+	     */
+	    if(IS_ISAKMP_SA_ESTABLISHED(st->st_state)) {
+		if(st->st_connection->dpd_delay>0
+		   && st->st_connection->dpd_timeout>0
+		   && st->st_dpd_event == NULL) {
+		    event_schedule(EVENT_DPD
+				   , st->st_connection->dpd_delay, st);
+		}
+	    }
+	     
+
 #ifdef XAUTH
 	    /* Special case for XAUTH server */
 	    if(st->st_connection->spd.this.xauth_server) {
@@ -2417,39 +2579,49 @@ complete_state_transition(struct msg_digest **mdp, stf_status result)
 	    if(!IS_QUICK(st->st_state)
 	       && st->st_connection->spd.this.xauth_client
 	       && !st->hidden_variables.st_xauth_client_done) {
-		DBG(DBG_CONTROL, DBG_log("XAUTH client is not yet authenticated"));
+	      DBG(DBG_CONTROL, DBG_log("XAUTH client is not yet authenticated"));
 	      break;
 	    }
+
 #endif
 
-	    if (smc->flags & SMF_RELEASE_PENDING_P2)
-	    {
-		/* Initiate any Quick Mode negotiations that
-		 * were waiting to piggyback on this Keying Channel.
-		 *
-		 * ??? there is a potential race condition
-		 * if we are the responder: the initial Phase 2
-		 * message might outrun the final Phase 1 message.
-		 * I think that retransmission will recover.
-		 */
-		unpend(st);
+#ifdef MODECFG
+	    /*
+	     * when talking to some vendors, we need to initiate a mode
+	     * cfg request to get challenged, but there is also an
+	     * override in the form of a policy bit.
+	     */
+	    DBG(DBG_CONTROL
+		, DBG_log("modecfg pull: %s policy:%s %s"
+			  , (st->quirks.modecfg_pull_mode
+			     ? "quirk-poll" : "noquirk")
+			  , (st->st_connection->policy & POLICY_MODECFG_PULL)
+			  ? "pull" : "push"
+			  , (st->st_connection->spd.this.modecfg_client
+			     ? "modecfg-client" :"not-client")));
+	    
+	    if(st->st_connection->spd.this.modecfg_client
+	       && IS_ISAKMP_SA_ESTABLISHED(st->st_state)
+	       && (st->quirks.modecfg_pull_mode
+		   || st->st_connection->policy & POLICY_MODECFG_PULL)
+	       && !st->hidden_variables.st_modecfg_started) {
+		DBG(DBG_CONTROL
+		    , DBG_log("modecfg client is starting due to %s"
+			      , st->quirks.modecfg_pull_mode ? "quirk" : "policy"));
+		modecfg_send_request(st);
+		break;
 	    }
 
-	    if (IS_ISAKMP_SA_ESTABLISHED(st->st_state)
-	    || IS_IPSEC_SA_ESTABLISHED(st->st_state))
-		release_whack(st);
-
-	    if (IS_QUICK(st->st_state))
-	      break;
-
-#ifdef MODECFG
 	    /* Should we set the peer's IP address regardless? */
-	    if(st->st_connection->spd.that.modecfg_server
-		   && IS_ISAKMP_SA_ESTABLISHED(st->st_state)
-	           && (st->st_seen_vendorid & (LELEM(VID_SAFENET)|LELEM(VID_NORTEL))))
+	    if(st->st_connection->spd.this.modecfg_server
+	       && IS_ISAKMP_SA_ESTABLISHED(st->st_state)
+	       && !st->hidden_variables.st_modecfg_vars_set 
+	       && !(st->st_connection->policy & POLICY_MODECFG_PULL))
 	    {
+		    st->st_state = STATE_MODE_CFG_R1;
+		    set_cur_state(st);
 		    openswan_log("Sending MODE CONFIG set");
-		    modecfg_send_set(st);
+		    modecfg_start_set(st);
 		    break;
 	    }
 
@@ -2464,8 +2636,47 @@ complete_state_transition(struct msg_digest **mdp, stf_status result)
 	        quick_outI1(st->st_whack_sock, st, st->st_connection, st->st_connection->policy, 1, SOS_NOBODY);
 		break;
 	    }	    
+
+	    /* wait for modecfg_set */
+	    if(st->st_connection->spd.this.modecfg_client
+	       && IS_ISAKMP_SA_ESTABLISHED(st->st_state)
+	       && !st->hidden_variables.st_modecfg_vars_set)
+	      {
+		  DBG(DBG_CONTROL
+		      , DBG_log("waiting for modecfg set from server"));
+		  break;
+	      }
 #endif
 
+	    DBG(DBG_CONTROL
+		, DBG_log("phase 1 is done, looking for phase 1 to unpend"));
+
+	    if (smc->flags & SMF_RELEASE_PENDING_P2)
+	    {
+		/* Initiate any Quick Mode negotiations that
+		 * were waiting to piggyback on this Keying Channel.
+		 *
+		 * ??? there is a potential race condition
+		 * if we are the responder: the initial Phase 2
+		 * message might outrun the final Phase 1 message.
+		 * I think that retransmission will recover.
+		 *
+		 * The same race condition exists if we are in aggressive
+		 * mode as the final phase 1 message might not have
+		 * been received yet, and in fact, we might even have
+		 * a situation where the responder does not accept our
+		 * our identification.
+		 */
+		unpend(st);
+	    }
+
+	    if (IS_ISAKMP_SA_ESTABLISHED(st->st_state)
+	    || IS_IPSEC_SA_ESTABLISHED(st->st_state))
+		release_whack(st);
+
+	    if (IS_QUICK(st->st_state))
+	      break;
+
 	    break;
 
 	case STF_INTERNAL_ERROR:
@@ -2504,9 +2715,14 @@ complete_state_transition(struct msg_digest **mdp, stf_status result)
 
 	    DBG(DBG_CONTROL,
 		DBG_log("state transition function for %s failed: %s"
-		    , enum_name(&state_names, from_state)
-		    , enum_name(&ipsec_notification_names, md->note)));
-	    break;
+			, enum_name(&state_names, from_state)
+			, enum_name(&ipsec_notification_names, md->note)));
+
+	    if(st!=NULL && IS_PHASE1_INIT(st->st_state)) {
+		delete_event(st);
+		release_whack(st);
+            }
+            break;
     }
 }
 
