@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: demux.h,v 1.28 2004/03/21 17:01:35 ken Exp $
+ * RCSID $Id: demux.h,v 1.31 2004/10/15 04:42:16 mcr Exp $
  */
 
 #ifndef _DEMUX_H
@@ -81,21 +81,9 @@ struct msg_digest {
     struct isakmp_quirks quirks;
 };
 
+extern struct msg_digest *alloc_md(void);
 extern void release_md(struct msg_digest *md);
 
-/* status for state-transition-function
- * Note: STF_FAIL + notification_t means fail with that notification
- */
-
-typedef enum {
-    STF_IGNORE,	/* don't respond */
-    STF_SUSPEND,    /* unfinished -- don't release resources */
-    STF_OK,	/* success */
-    STF_INTERNAL_ERROR,	/* discard everything, we failed */
-    STF_FAIL,	/* discard everything, something failed.  notification_t added. */
-    STF_FATAL,  /* just stop. we can't continue */
-} stf_status;
-
 typedef stf_status state_transition_fn(struct msg_digest *md);
 
 extern void complete_state_transition(struct msg_digest **mdp, stf_status result);
