@@ -66,4 +66,10 @@ static __inline__ struct encrypt_desc *ike_alg_get_encrypter(int alg)
 	return (struct encrypt_desc *) ike_alg_find(IKE_ALG_ENCRYPT, alg, 0);
 }
 const struct oakley_group_desc * ike_alg_pfsgroup(struct connection *c, lset_t policy);
+
+extern struct db_sa *oakley_alg_makedb(struct alg_info_ike *ai
+				       , struct db_sa *basic
+				       , int maxtrans);
+
+extern struct db_sa *kernel_alg_makedb(struct alg_info_esp *ai);
 #endif /* _IKE_ALG_H */
