@@ -11,13 +11,15 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: ipsec_doi.h,v 1.35 2004/06/14 01:46:02 mcr Exp $
+ * RCSID $Id: ipsec_doi.h,v 1.39 2004/11/30 16:07:58 mcr Exp $
  */
 
 extern void echo_hdr(struct msg_digest *md, bool enc, u_int8_t np);
 
 extern void ipsecdoi_initiate(int whack_sock, struct connection *c
-    , lset_t policy, unsigned long try, so_serial_t replacing);
+			      , lset_t policy, unsigned long try
+			      , so_serial_t replacing
+			      , enum crypto_importance importance);
 
 extern void ipsecdoi_replace(struct state *st, unsigned long try);
 
@@ -37,7 +39,8 @@ extern state_transition_fn
     main_inR2_outI3,
     main_inI3_outR3,
     main_inR3,
-    aggr_inI1_outR1,
+    aggr_inI1_outR1_psk,
+    aggr_inI1_outR1_rsasig,
     aggr_inR1_outI2,
     aggr_inI2,
     quick_inI1_outR1,
@@ -60,7 +63,6 @@ extern const char *init_pluto_vendorid(void);
 extern void close_message(pb_stream *pbs); /* forward declaration */
 extern bool encrypt_message(pb_stream *pbs, struct state *st); /* forward declaration */
 
-extern void dpd_outI(struct state *st);
 extern stf_status dpd_inI_outR(struct state *st
             , struct isakmp_notification *const n, pb_stream *n_pbs);
 extern stf_status dpd_inR(struct state *st
@@ -106,3 +108,8 @@ extern void dpd_timeout(struct state *st);
 	    return STF_FAIL + INVALID_HASH_INFORMATION; \
 	} \
     }
+
+extern stf_status
+send_isakmp_notification(struct state *st
+			 , u_int16_t type, const void *data, size_t len);
+
