@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: kernel.c,v 1.210 2004/06/14 01:46:02 mcr Exp $
+ * RCSID $Id: kernel.c,v 1.215.2.1 2004/12/21 21:01:36 mcr Exp $
  */
 
 #include <stddef.h>
@@ -686,7 +686,9 @@ could_route(struct connection *c)
     /* if this is a Road Warrior template, we cannot route.
      * Opportunistic template is OK.
      */
-    if (c->kind == CK_TEMPLATE && !(c->policy & POLICY_OPPO))
+    if (!c->spd.that.has_client
+	&& c->kind == CK_TEMPLATE
+	&& !(c->policy & POLICY_OPPO))
     {
         loglog(RC_ROUTE, "cannot route template policy of %s",
                prettypolicy(c->policy));
@@ -1875,8 +1877,10 @@ setup_half_ipsec_sa(struct state *st, bool inbound)
         said_next->satype = SADB_X_SATYPE_IPIP;
         said_next->text_said = text_said;
 
-        if (!kernel_ops->add_sa(said_next, replace))
+        if (!kernel_ops->add_sa(said_next, replace)) {
+	    DBG_log("add_sa tunnel failed");
             goto fail;
+	}
 
         said_next++;
 
@@ -1917,8 +1921,10 @@ setup_half_ipsec_sa(struct state *st, bool inbound)
         said_next->reqid = c->spd.reqid + 2;
         said_next->text_said = text_said;
 
-        if (!kernel_ops->add_sa(said_next, replace))
+        if (!kernel_ops->add_sa(said_next, replace)) {
+	    DBG_log("add_sa ipcomp failed");
             goto fail;
+	}
 
         said_next++;
 
@@ -1935,33 +1941,45 @@ setup_half_ipsec_sa(struct state *st, bool inbound)
         u_int16_t key_len;
 
         static const struct esp_info esp_info[] = {
-            { ESP_NULL, AUTH_ALGORITHM_HMAC_MD5,
+            { FALSE, ESP_NULL, AUTH_ALGORITHM_HMAC_MD5,
                 0, HMAC_MD5_KEY_LEN,
                 SADB_EALG_NULL, SADB_AALG_MD5HMAC },
-            { ESP_NULL, AUTH_ALGORITHM_HMAC_SHA1,
+            { FALSE, ESP_NULL, AUTH_ALGORITHM_HMAC_SHA1,
                 0, HMAC_SHA1_KEY_LEN,
                 SADB_EALG_NULL, SADB_AALG_SHA1HMAC },
 
-            { ESP_DES, AUTH_ALGORITHM_NONE,
+            { FALSE, ESP_DES, AUTH_ALGORITHM_NONE,
                 DES_CBC_BLOCK_SIZE, 0,
                 SADB_EALG_DESCBC, SADB_AALG_NONE },
-            { ESP_DES, AUTH_ALGORITHM_HMAC_MD5,
+            { FALSE, ESP_DES, AUTH_ALGORITHM_HMAC_MD5,
                 DES_CBC_BLOCK_SIZE, HMAC_MD5_KEY_LEN,
                 SADB_EALG_DESCBC, SADB_AALG_MD5HMAC },
-            { ESP_DES, AUTH_ALGORITHM_HMAC_SHA1,
+            { FALSE, ESP_DES, AUTH_ALGORITHM_HMAC_SHA1,
                 DES_CBC_BLOCK_SIZE,
                 HMAC_SHA1_KEY_LEN, SADB_EALG_DESCBC, SADB_AALG_SHA1HMAC },
 
-            { ESP_3DES, AUTH_ALGORITHM_NONE,
+            { FALSE, ESP_3DES, AUTH_ALGORITHM_NONE,
                 DES_CBC_BLOCK_SIZE * 3, 0,
                 SADB_EALG_3DESCBC, SADB_AALG_NONE },
-            { ESP_3DES, AUTH_ALGORITHM_HMAC_MD5,
+            { FALSE, ESP_3DES, AUTH_ALGORITHM_HMAC_MD5,
                 DES_CBC_BLOCK_SIZE * 3, HMAC_MD5_KEY_LEN,
                 SADB_EALG_3DESCBC, SADB_AALG_MD5HMAC },
-            { ESP_3DES, AUTH_ALGORITHM_HMAC_SHA1,
+            { FALSE, ESP_3DES, AUTH_ALGORITHM_HMAC_SHA1,
                 DES_CBC_BLOCK_SIZE * 3, HMAC_SHA1_KEY_LEN,
                 SADB_EALG_3DESCBC, SADB_AALG_SHA1HMAC },
+
+            { FALSE, ESP_AES, AUTH_ALGORITHM_NONE,
+                AES_CBC_BLOCK_SIZE, 0,
+                SADB_X_EALG_AESCBC, SADB_AALG_NONE },
+            { FALSE, ESP_AES, AUTH_ALGORITHM_HMAC_MD5,
+                AES_CBC_BLOCK_SIZE, HMAC_MD5_KEY_LEN,
+                SADB_X_EALG_AESCBC, SADB_AALG_MD5HMAC },
+            { FALSE, ESP_AES, AUTH_ALGORITHM_HMAC_SHA1,
+                AES_CBC_BLOCK_SIZE, HMAC_SHA1_KEY_LEN,
+                SADB_X_EALG_AESCBC, SADB_AALG_SHA1HMAC },
         };
+	//static const int esp_max = elemsof(esp_info);
+	//int esp_count;
 
 #ifdef NAT_TRAVERSAL
         u_int8_t natt_type = 0;
@@ -1979,12 +1997,15 @@ setup_half_ipsec_sa(struct state *st, bool inbound)
 
         for (ei = esp_info; ; ei++)
         {
+	    
+	    /* if it is the last key entry, then ask algo */
             if (ei == &esp_info[elemsof(esp_info)])
             {
                 /* Check for additional kernel alg */
 #ifdef KERNEL_ALG
-                if ((ei=kernel_alg_esp_info(st->st_esp.attrs.transid, 
-                                        st->st_esp.attrs.auth))!=NULL) {
+                if ((ei=kernel_alg_esp_info(st->st_esp.attrs.transid,
+					    st->st_esp.attrs.key_len,
+					    st->st_esp.attrs.auth))!=NULL) {
                         break;
                 }
 #endif
@@ -2001,10 +2022,20 @@ setup_half_ipsec_sa(struct state *st, bool inbound)
             }
 
             if (st->st_esp.attrs.transid == ei->transid
-            && st->st_esp.attrs.auth == ei->auth)
+		&& st->st_esp.attrs.key_len == ei->enckeylen*8  
+		&& st->st_esp.attrs.auth == ei->auth)
                 break;
         }
 
+	if (st->st_esp.attrs.transid != ei->transid
+	    && st->st_esp.attrs.key_len != ei->enckeylen*8  
+	    && st->st_esp.attrs.auth != ei->auth) {
+	    loglog(RC_LOG_SERIOUS, "failed to find key info for %s/%s"
+		   , enum_name(&esp_transformid_names, st->st_esp.attrs.transid)
+		   , enum_name(&auth_alg_names, st->st_esp.attrs.auth));
+	    goto fail;
+	}
+
         key_len = st->st_esp.attrs.key_len/8;
         if (key_len) {
                 /* XXX: must change to check valid _range_ key_len */
@@ -2029,11 +2060,9 @@ setup_half_ipsec_sa(struct state *st, bool inbound)
 
         /* divide up keying material */
         /* passert(st->st_esp.keymat_len == ei->enckeylen + ei->authkeylen); */
-        DBG(DBG_KLIPS|DBG_CONTROL|DBG_PARSING, 
-                if(st->st_esp.keymat_len != key_len + ei->authkeylen)
-                        DBG_log("keymat_len=%d key_len=%d authkeylen=%d",
-                                st->st_esp.keymat_len, (int)key_len, (int)ei->authkeylen);
-        );
+	if(st->st_esp.keymat_len != key_len + ei->authkeylen)
+	    DBG_log("keymat_len=%d key_len=%d authkeylen=%d",
+		    st->st_esp.keymat_len, (int)key_len, (int)ei->authkeylen);
         passert(st->st_esp.keymat_len == (key_len + ei->authkeylen));
 
         set_text_said(text_said, &dst.addr, esp_spi, SA_ESP);
