@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: log.c,v 1.87 2004/06/14 01:46:03 mcr Exp $
+ * RCSID $Id: log.c,v 1.90 2004/11/15 14:34:03 mcr Exp $
  */
 
 #include <stdio.h>
@@ -83,6 +83,18 @@ bool
 const char *base_perpeer_logdir = PERPEERLOGDIR;
 static int perpeer_count = 0;
 
+/* what to put in front of debug output */
+char debug_prefix = '|';
+
+/*
+ * used in some messages to distiguish
+ * which pluto is which, when doing unit testing
+ * gets set by "use_interface" in server.c, if it is going to be changed.
+ * Is used by pluto_helpers in their process-title.
+ * could be used by debug routines as well, but is not yet.
+ */
+const char *pluto_ifn_inst = "";  
+
 /* from sys/queue.h */
 static CIRCLEQ_HEAD(,connection) perpeer_list;
 
@@ -570,6 +582,7 @@ switch_fail(int n, const char *file_str, unsigned long line_no)
 
     snprintf(buf, sizeof(buf), "case %d unexpected", n);
     passert_fail(buf, file_str, line_no);
+    /* NOTREACHED */
 }
 
 void
@@ -638,11 +651,16 @@ DBG_log(const char *message, ...)
     (void)sanitize_string(m, sizeof(m));
 
     if (log_to_stderr)
-	fprintf(stderr, "| %s\n", m);
+	fprintf(stderr, "%c %s\n", debug_prefix, m);
     if (log_to_syslog)
-	syslog(LOG_DEBUG, "| %s", m);
-    if (log_to_perpeer)
-	peerlog("| ", m);
+	syslog(LOG_DEBUG, "%c %s", debug_prefix, m);
+    if (log_to_perpeer) {
+	char prefix[3];
+	prefix[0]=debug_prefix;
+	prefix[1]=' ';
+	prefix[2]='\n';
+	peerlog(prefix, m);
+    }
 }
 
 /* dump raw bytes in hex to stderr (for lack of any better destination) */
