@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: nat_traversal.c,v 1.11 2004/06/27 09:43:59 ken Exp $
+ * RCSID $Id: nat_traversal.c,v 1.15 2004/11/30 02:31:14 mcr Exp $
  */
 
 #ifdef NAT_TRAVERSAL
@@ -94,6 +94,10 @@ void init_nat_traversal (bool activate, unsigned int keep_alive_period,
 	nat_traversal_support_non_ike = activate;
 #ifdef NAT_T_SUPPORT_LAST_DRAFTS
 	nat_traversal_support_port_floating = activate ? spf : FALSE;
+	openswan_log("Setting port floating to %s"
+		     , nat_traversal_support_port_floating ? "on" : "off");
+	openswan_log("port floating activate %d/%d"
+		     , activate, spf);
 #endif
 	_force_ka = fka;
 	_kap = keep_alive_period ? keep_alive_period : DEFAULT_KEEP_ALIVE_PERIOD;
@@ -107,8 +111,10 @@ static void disable_nat_traversal(int type)
 {
 	if (type == ESPINUDP_WITH_NON_IKE)
 		nat_traversal_support_non_ike = FALSE;
-	else
-		nat_traversal_support_port_floating = FALSE;
+	else {
+	  openswan_log("port floating turned off");
+	  nat_traversal_support_port_floating = FALSE;
+	}
 
 	if (!nat_traversal_support_non_ike &&
 	    !nat_traversal_support_port_floating)
@@ -549,14 +555,14 @@ void nat_traversal_show_result (u_int32_t nt, u_int16_t sport)
 	}
 }
 
-int nat_traversal_espinudp_socket (int sk, u_int32_t type)
+int nat_traversal_espinudp_socket (int sk, const char *fam, u_int32_t type)
 {
 	int r;
 	r = setsockopt(sk, SOL_UDP, UDP_ESPINUDP, &type, sizeof(type));
 	if ((r<0) && (errno == ENOPROTOOPT)) {
 		loglog(RC_LOG_SERIOUS,
-			"NAT-Traversal: ESPINUDP(%d) not supported by kernel -- "
-			"NAT-T disabled", type);
+		       "NAT-Traversal: ESPINUDP(%d) not supported by kernel for family %s"
+		       , type, fam);
 		disable_nat_traversal(type);
 	}
 	return r;
@@ -600,7 +606,9 @@ static void nat_traversal_ka_event_state (struct state *st, void *data)
 	const struct connection *c = st->st_connection;
 	if (!c) return;
 	if ( ((st->st_state == STATE_MAIN_R3) ||
-			(st->st_state == STATE_MAIN_I4)) &&
+			(st->st_state == STATE_MAIN_I4) ||
+			(st->st_state == STATE_AGGR_R2) ||
+			(st->st_state == STATE_AGGR_I2)) &&
 		(st->nat_traversal & NAT_T_DETECTED) &&
 		((st->nat_traversal & LELEM(NAT_TRAVERSAL_NAT_BHND_ME)) || (_force_ka))
 		) {
@@ -860,3 +868,18 @@ void process_pfkey_nat_t_new_mapping(
 
 #endif
 
+/*
+ * $Log: nat_traversal.c,v $
+ * Revision 1.15  2004/11/30 02:31:14  mcr
+ * 	oops, function didn't match prototype.
+ *
+ * Revision 1.14  2004/11/30 02:26:59  mcr
+ * 	additional debugging of port-floating enabling/disabling.
+ *
+ * Revision 1.13  2004/11/05 00:14:50  mcr
+ * 	added log info.
+ *
+ *
+ * $Id: nat_traversal.c,v 1.15 2004/11/30 02:31:14 mcr Exp $
+ *
+ */
