@@ -13,7 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: plutomain.c,v 1.93 2004/06/26 23:17:52 ken Exp $
+ * RCSID $Id: plutomain.c,v 1.96 2004/10/18 00:07:39 mcr Exp $
  */
 
 #include <stdio.h>
@@ -68,6 +68,7 @@
 #include "md5.h"
 #include "crypto.h"	/* requires sha1.h and md5.h */
 #include "vendor.h"
+#include "pluto_crypt.h"
 
 #ifdef VIRTUAL_IP
 #include "virtual.h"
@@ -83,6 +84,8 @@
 
 const char *ipsec_dir = IPSECDIR;
 
+openswan_passert_fail_t openswan_passert_fail = passert_fail;
+
 /** usage - print help messages
  *
  * @param mess String - alternate message to print
@@ -118,6 +121,7 @@ usage(const char *mess)
 	    " [--ipsecdir <ipsec-dir>]"
 	    " \\\n\t"
 	    "[--adns <pathname>]"
+	    "[--nhelpers <number>]"
 #ifdef DEBUG
 	    " \\\n\t"
 	    "[--debug-none]"
@@ -131,6 +135,7 @@ usage(const char *mess)
 	    "[--debug-control]"
 	    " [--debug-klips]"
 	    " [--debug-dns]"
+	    " [--debug-dpd]"
 	    " [ --debug-private]"
 	    " [ --debug-pfkey]"
 #endif
@@ -228,6 +233,9 @@ bool strict_crl_policy = FALSE;
 /** by default pluto does not check crls dynamically */
 long crl_check_interval = 0;
 
+char **global_argv;
+int    global_argc;
+
 int
 main(int argc, char **argv)
 {
@@ -235,6 +243,8 @@ main(int argc, char **argv)
     bool log_to_stderr_desired = FALSE;
     int lockfd;
     char* ocspuri = NULL;
+    int nhelpers = -1;
+    char *coredir;
 
 #ifdef NAT_TRAVERSAL
     /** Overridden by nat_traversal= in ipsec.conf */
@@ -248,6 +258,13 @@ main(int argc, char **argv)
     char *virtual_private = NULL;
 #endif
 
+    global_argv = argv;
+    global_argc = argc;
+    openswan_passert_fail = passert_fail;
+
+    /* see if there is an environment variable */
+    coredir = getenv("PLUTO_CORE_DIR");
+
     /* handle arguments */
     for (;;)
     {
@@ -274,6 +291,7 @@ main(int argc, char **argv)
 	    { "perpeerlogbase", required_argument, NULL, 'P' },
 	    { "perpeerlog", no_argument, NULL, 'l' },
 	    { "noretransmits", no_argument, NULL, 'R' },
+	    { "coredir", required_argument, NULL, 'C' },
 	    { "ipsecdir", required_argument, NULL, 'f' },
 	    { "ipsec_dir", required_argument, NULL, 'f' },
 #ifdef USE_LWRES
@@ -291,6 +309,7 @@ main(int argc, char **argv)
 #ifdef VIRTUAL_IP
 	    { "virtual_private", required_argument, NULL, '6' },
 #endif
+	    { "nhelpers", required_argument, NULL, 'j' },
 #ifdef DEBUG
 	    { "debug-none", no_argument, NULL, 'N' },
 	    { "debug-all]", no_argument, NULL, 'A' },
@@ -305,6 +324,7 @@ main(int argc, char **argv)
 	    { "debug-dns", no_argument, NULL, DBG_DNS + DBG_OFFSET },
 	    { "debug-oppo", no_argument, NULL, DBG_OPPO + DBG_OFFSET },
 	    { "debug-controlmore", no_argument, NULL, DBG_CONTROLMORE + DBG_OFFSET },
+	    { "debug-dpd", no_argument, NULL, DBG_DPD + DBG_OFFSET },
 	    { "debug-private", no_argument, NULL, DBG_PRIVATE + DBG_OFFSET },
 	    { "debug-pfkey", no_argument, NULL, DBG_PFKEY + DBG_OFFSET },
 
@@ -339,6 +359,10 @@ main(int argc, char **argv)
 	    usage(NULL);
 	    break;	/* not actually reached */
 
+	case 'C':
+	    coredir = clone_str(optarg, "coredir");
+	    break;
+
 	case 'v':	/* --version */
 	    {
 		const char **sp = ipsec_copyright_notice();
@@ -356,6 +380,21 @@ main(int argc, char **argv)
 	    /* does not return on error */
 	    continue;
 
+	case 'j':	/* --nhelpers */
+            if (optarg == NULL || !isdigit(optarg[0]))
+                usage("missing number of pluto helpers");
+
+            {
+                char *endptr;
+                long count = strtol(optarg, &endptr, 0);
+
+                if (*endptr != '\0' || endptr == optarg
+		    || count < -1)
+                    usage("<interval-time> must be a positive number, 0 or -1");
+                nhelpers = count;
+            }
+	    continue;
+
 	case 'd':	/* --nofork*/
 	    fork_desired = FALSE;
 	    continue;
@@ -507,6 +546,12 @@ main(int argc, char **argv)
     if (optind != argc)
 	usage("unexpected argument");
     reset_debugging();
+
+    /* if a core dir was set, chdir there */
+    if(coredir) {
+	chdir(coredir);
+    }
+
     lockfd = create_lock();
 
     /* select between logging methods */
@@ -641,6 +686,10 @@ main(int argc, char **argv)
 #endif
     }
 
+    if(coredir) {
+	openswan_log("core dump dir: %s", coredir);
+    }
+
 /** Initialize all of the various features */
 
 #ifdef NAT_TRAVERSAL
@@ -654,6 +703,7 @@ main(int argc, char **argv)
     init_secret();
     init_states();
     init_crypto();
+    init_crypto_helpers(nhelpers);
     init_demux();
     init_kernel();
     init_adns();
