@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: rcv_whack.c,v 1.107 2004/06/14 02:01:32 mcr Exp $
+ * RCSID $Id: rcv_whack.c,v 1.110.2.1 2004/12/21 23:09:06 ken Exp $
  */
 
 #include <stdio.h>
@@ -60,6 +60,7 @@
 #include "server.h"
 #include "fetch.h"
 #include "ocsp.h"
+#include "timer.h"
 
 #include "kernel_alg.h"
 #include "ike_alg.h"
@@ -285,7 +286,7 @@ whack_handle(int whackctlfd)
 	    }
 	    else
 	    {
-		ugh = builddiag("ignoring message from whack with bad magic %d; should be %d; probably wrong version"
+		ugh = builddiag("ignoring message from whack with bad magic %d; should be %d; Mismatched versions of userland tools and kernel code."
 		    , msg.magic, WHACK_MAGIC);
 	    }
 	}
@@ -491,6 +492,11 @@ whack_handle(int whackctlfd)
     }
 #endif
 
+    if (msg.whack_list & LIST_EVENTS)
+    {
+	timer_list();
+    }
+
     if (msg.whack_key)
     {
 	/* add a public key */
@@ -552,7 +558,8 @@ whack_handle(int whackctlfd)
 	    whack_log(RC_DEAF, "need --listen before --initiate");
 	else
 	    initiate_connection(msg.name
-		, msg.whack_async? NULL_FD : dup_any(whackfd));
+				, msg.whack_async? NULL_FD : dup_any(whackfd)
+				, pcim_demand_crypto);
     }
 
     if (msg.whack_oppo_initiate)
