@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: server.c,v 1.97.6.2 2004/08/07 01:47:45 ken Exp $
+ * RCSID $Id: server.c,v 1.103 2004/11/30 02:28:07 mcr Exp $
  */
 
 #include <stdio.h>
@@ -40,6 +40,8 @@
 #include <resolv.h>
 #include <arpa/nameser.h>	/* missing from <resolv.h> on old systems */
 #include <sys/queue.h>
+#include <sys/resource.h>
+#include <sys/wait.h>
 
 #include <openswan.h>
 
@@ -67,6 +69,7 @@
 #include "adns.h"	/* needs <resolv.h> */
 #include "dnskey.h"	/* needs keys.h and adns.h */
 #include "whack.h"	/* for RC_LOG_SERIOUS */
+#include "pluto_crypt.h" /* cryptographic helper functions */
 
 #include <pfkeyv2.h>
 #include <pfkey.h>
@@ -270,6 +273,10 @@ static int pluto_ifn_roof = 0;
 bool
 use_interface(const char *rifn)
 {
+    if(pluto_ifn_inst[0]=='\0') {
+	pluto_ifn_inst = clone_str(rifn, "genifn");
+    }
+
     if (pluto_ifn_roof >= (int)elemsof(pluto_ifn))
     {
 	return FALSE;
@@ -712,7 +719,7 @@ add_entry:
 #ifdef NAT_TRAVERSAL
 		    if (nat_traversal_support_non_ike && addrtypeof(&ifp->addr) == AF_INET)
 		    {
-			nat_traversal_espinudp_socket(fd, ESPINUDP_WITH_NON_IKE);
+			nat_traversal_espinudp_socket(fd, "IPv4", ESPINUDP_WITH_NON_IKE);
 		    }
 #endif
 
@@ -729,10 +736,10 @@ add_entry:
 #ifdef NAT_TRAVERSAL
 		    if (nat_traversal_support_port_floating && addrtypeof(&ifp->addr) == AF_INET) {
 			fd = create_socket(ifp, v->name, NAT_T_IKE_FLOAT_PORT);
-			if (fd < 0)
+			if (fd < 0) 
 			    break;
-			nat_traversal_espinudp_socket(fd,
-			    ESPINUDP_WITH_NON_ESP);
+			nat_traversal_espinudp_socket(fd, "IPv4"
+						      , ESPINUDP_WITH_NON_ESP);
 			q = alloc_thing(struct iface, "struct iface");
 			q->rname = clone_str(ifp->name, "real device name");
 			q->vname = clone_str(v->name, "virtual device name");
@@ -834,6 +841,32 @@ termhandler(int sig UNUSED)
     sigtermflag = TRUE;
 }
 
+static volatile sig_atomic_t sigchildflag = FALSE;
+
+static void
+childhandler(int sig UNUSED)
+{
+    sigchildflag = TRUE;
+}
+
+/* perform wait4() on all children */
+static void
+reapchildren(void)
+{
+    pid_t child;
+    int status;
+    struct rusage r;
+
+    sigchildflag = FALSE;
+    while((child = wait3(&status, WNOHANG, &r)) != 0) {
+	/* got a child to reap */
+	if(adns_reapchild(child, status)) continue;
+	if(pluto_crypt_handle_dead_child(child, status)) continue;
+	
+	openswan_log("child pid=%d (status=%d) is not my child!", child, status);
+    }
+}
+
 /* call_server listens for incoming ISAKMP packets and Whack messages,
  * and handles timer events.
  */
@@ -856,6 +889,11 @@ call_server(void)
 	act.sa_handler = &termhandler;
 	r = sigaction(SIGTERM, &act, NULL);
 	passert(r == 0);
+
+	act.sa_handler = &childhandler;
+	act.sa_flags   = SA_RESTART;
+	r = sigaction(SIGCHLD, &act, NULL);
+	passert(r == 0);
     }
 
     for (;;)
@@ -885,6 +923,10 @@ call_server(void)
 		openswan_log("Pluto ignores SIGHUP -- perhaps you want \"whack --listen\"");
 	    }
 
+	    if(sigchildflag) {
+		reapchildren();
+	    }
+
 	    FD_ZERO(&readfds);
 	    FD_ZERO(&writefds);
 	    FD_SET(ctl_fd, &readfds);
@@ -934,6 +976,9 @@ call_server(void)
 		}
 	    }
 
+	    /* see if helpers need attention */
+	    pluto_crypto_helper_sockets(&readfds);
+
 	    if (no_retransmits || next_time < 0)
 	    {
 		/* select without timer */
@@ -1058,6 +1103,9 @@ call_server(void)
 	    }
 #endif
 
+	    /* note we process helper things last on purpose */
+	    ndes -= pluto_crypto_helper_ready(&readfds);
+
 	    passert(ndes == 0);
 	}
     }
