@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: spdb.h,v 1.14 2004/04/18 03:06:46 mcr Exp $
+ * RCSID $Id: spdb.h,v 1.17 2004/10/18 00:08:27 mcr Exp $
  */
 
 #ifndef _SPDB_H_
@@ -64,6 +64,11 @@ struct db_sa {
  * from POLICY_PSK and POLICY_RSASIG.
  */
 extern struct db_sa oakley_sadb[1 << 4];
+extern struct db_sa oakley_am_sadb[1 << 4];
+
+/* The oakley sadb for aggressive mode.
+ */
+extern struct db_sa oakley_sadb_am;
 
 /* The ipsec sadb is subscripted by a bitset with members
  * from POLICY_ENCRYPT, POLICY_AUTHENTICATE, POLICY_COMPRESS
@@ -75,8 +80,16 @@ extern bool out_sa(
     struct db_sa *sadb,
     struct state *st,
     bool oakley_mode,
+    bool aggressive_mode,
     u_int8_t np);
 
+#if 0
+extern complaint_t accept_oakley_auth_method(
+    struct state *st,   /* current state object */
+    u_int32_t amethod,  /* room for larger values */
+    bool credcheck);    /* whether we can check credentials now */
+#endif
+
 extern notification_t parse_isakmp_sa_body(
     pb_stream *sa_pbs,	/* body of input SA Payload */
     const struct isakmp_sa *sa,	/* header of input SA Payload */
@@ -84,6 +97,9 @@ extern notification_t parse_isakmp_sa_body(
     bool selection,	/* if this SA is a selection, only one tranform can appear */
     struct state *st);	/* current state object */
 
+/* initialize a state with the aggressive mode parameters */
+extern int init_am_st_oakley(struct state *st, lset_t policy);
+
 extern notification_t parse_ipsec_sa_body(
     pb_stream *sa_pbs,	/* body of input SA Payload */
     const struct isakmp_sa *sa,	/* header of input SA Payload */
@@ -91,4 +107,23 @@ extern notification_t parse_ipsec_sa_body(
     bool selection,	/* if this SA is a selection, only one tranform can appear */
     struct state *st);	/* current state object */
 
+extern void free_sa_attr(struct db_attr *attr);
+extern void free_sa_trans(struct db_trans *tr);
+extern void free_sa_prop(struct db_prop *dp);
+extern void free_sa_prop_conj(struct db_prop_conj *pc);
+extern void free_sa(struct db_sa *f);
+extern void clone_trans(struct db_trans *tr);
+extern void clone_prop(struct db_prop *p, int extra);
+extern void clone_propconj(struct db_prop_conj *pc, int extra);
+extern struct db_sa *sa_copy_sa(struct db_sa *sa, int extra);
+extern struct db_sa *sa_copy_sa_first(struct db_sa *sa);
+extern struct db_sa *sa_merge_proposals(struct db_sa *a, struct db_sa *b);
+
+
+/* in spdb_struct.c */
+extern bool out_attr(int type, unsigned long val, struct_desc *attr_desc
+		     , enum_names **attr_val_descs USED_BY_DEBUG
+		     , pb_stream *pbs);
+
+
 #endif /*  _SPDB_H_ */
