@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: state.c,v 1.130.2.1 2004/08/22 03:25:30 mcr Exp $
+ * RCSID $Id: state.c,v 1.136 2004/11/30 15:30:02 mcr Exp $
  */
 
 #include <stdio.h>
@@ -832,12 +832,9 @@ void fmt_state(struct state *st, time_t n
 {
     /* what the heck is interesting about a state? */
     const struct connection *c = st->st_connection;
-
-    long delta = st->st_event->ev_time >= n
-	? (long)(st->st_event->ev_time - n)
-	: -(long)(n - st->st_event->ev_time);
-
+    long delta;
     char inst[CONN_INST_BUF];
+    char dpdbuf[128];
     const char *np1 = c->newest_isakmp_sa == st->st_serialno
 	? "; newest ISAKMP" : "";
     const char *np2 = c->newest_ipsec_sa == st->st_serialno
@@ -846,19 +843,40 @@ void fmt_state(struct state *st, time_t n
     const char *eo = c->spd.eroute_owner == st->st_serialno
 	? "; eroute owner" : "";
 
-    passert(st->st_event != 0);
-
     fmt_conn_instance(c, inst);
 
+    if(st->st_event) {
+	delta = st->st_event->ev_time >= n
+	    ? (long)(st->st_event->ev_time - n)
+	    : -(long)(n - st->st_event->ev_time);
+    } else {
+	delta = -1;
+    }
+
+    if (IS_IPSEC_SA_ESTABLISHED(st->st_state))
+    {
+	dpdbuf[0]='\0';
+    } else {
+	if(st->hidden_variables.st_dpd) {
+	    time_t n = time(NULL);
+	    snprintf(dpdbuf, sizeof(dpdbuf), "; lastdpd=%lds(seq in:%u out:%u)"
+		     , st->st_last_dpd !=0 ? n - st->st_last_dpd : -1
+		     , st->st_dpd_seqno
+		     , st->st_dpd_expectseqno);
+	} else {
+	    snprintf(dpdbuf, sizeof(dpdbuf), "; nodpd");
+	}
+    }
+	
     snprintf(state_buf, state_buf_len
-	, "#%lu: \"%s\"%s %s (%s); %s in %lds%s%s%s"
+	, "#%lu: \"%s\"%s %s (%s); %s in %lds%s%s%s%s"
 	, st->st_serialno
 	, c->name, inst
 	, enum_name(&state_names, st->st_state)
 	, state_story[st->st_state - STATE_MAIN_R0]
-	, enum_name(&timer_event_names, st->st_event->ev_type)
+	     , st->st_event ? enum_name(&timer_event_names, st->st_event->ev_type) : "none"
 	, delta
-	, np1, np2, eo);
+	     , np1, np2, eo, dpdbuf);
 
     /* print out SPIs if SAs are established */
     if (state_buf2_len != 0)
@@ -1124,6 +1142,14 @@ void replace_states_by_peer(ip_address *peer)
             }
 }
 
+void copy_quirks(struct isakmp_quirks *dq
+		 , struct isakmp_quirks *sq)
+{
+    dq->xauth_ack_msgid   |= sq->xauth_ack_msgid;
+    dq->modecfg_pull_mode |= sq->modecfg_pull_mode;
+    dq->nat_traversal_vid |= sq->nat_traversal_vid;
+}
+
 /*
  * Local Variables:
  * c-basic-offset:4
