@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: state.h,v 1.82 2004/05/05 03:00:39 ken Exp $
+ * RCSID $Id: state.h,v 1.88 2004/11/30 15:30:02 mcr Exp $
  */
 
 #include <sys/types.h>
@@ -58,7 +58,7 @@ struct oakley_trans_attrs {
     const struct encrypt_desc *encrypter;	/* package of encryption routines */
     u_int16_t hash;		/* Hash algorithm */
     const struct hash_desc *hasher;	/* package of hashing routines */
-    u_int16_t auth;		/* Authentication method */
+    oakley_auth_t auth;		/* Authentication method */
 #ifdef XAUTH
     u_int16_t xauth;            /* did we negotiate Extended Authentication? */
 #endif
@@ -140,7 +140,7 @@ struct state
 
     msgid_t            st_msgid;               /* MSG-ID from header.  Network Order! */
     msgid_t            st_msgid2;              /* MSG-ID from header.  Network Order! */
-
+  
 #define MAX_INFO_EXG 16
     msgid_t            st_infoid[MAX_INFO_EXG];/* space for possible informational exchanges */
 
@@ -186,6 +186,9 @@ struct state
                                                 * presence indicates PFS
                                                 * selected.
                                                 */
+    enum crypto_importance st_import;          /* relative priority of crypto
+						* operations
+						*/
 
     /* In a Phase 1 state, preserve peer's public key after authentication */
     struct pubkey     *st_peer_pubkey;
@@ -218,9 +221,16 @@ struct state
     struct state      *st_hashchain_prev;      /* Previous in list */
 
     struct {
+        unsigned int   st_malformed_received;
+        unsigned int   st_malformed_sent;
 	bool           st_xauth_client_done;
 	int            st_xauth_client_attempt;
+        bool           st_modecfg_server_done;
+        bool           st_modecfg_vars_set;
 	bool           st_got_certrequest;
+        bool           st_modecfg_started;
+	bool           st_dpd;                 /* Peer supports DPD */
+	bool           st_dpd_local;		/* If we want DPD on this conn */
     } hidden_variables;                        /* internal state that
 						* should get copied by god
 						* Eistein would be proud
@@ -233,8 +243,6 @@ struct state
 #endif
 
     /* RFC 3706 Dead Peer Detection */
-    bool                st_dpd;                 /* Peer supports DPD */
-    bool                st_dpd_local;		/* If we want DPD on this conn */
     time_t              st_last_dpd;            /* Time of last DPD transmit */
     u_int32_t           st_dpd_seqno;           /* Next R_U_THERE to send */
     u_int32_t           st_dpd_expectseqno;     /* Next R_U_THERE_ACK to receive */
@@ -302,3 +310,10 @@ extern void fmt_state(struct state *st, time_t n
 extern void delete_states_by_peer(ip_address *peer);
 extern void replace_states_by_peer(ip_address *peer);
 
+
+/*
+ * Local Variables:
+ * c-basic-offset:4
+ * c-style: pluto
+ * End:
+ */
