@@ -1,7 +1,7 @@
 #!/bin/sh
 
 #
-# $Id: functions.sh,v 1.108 2004/05/19 14:53:31 mcr Exp $
+# $Id: functions.sh,v 1.117 2004/11/09 18:36:35 ken Exp $
 #
 
 preptest() {
@@ -577,10 +577,16 @@ netjigtest() {
     pcap_filter private "$REF_PRIV_OUTPUT" "$PRIVOUTPUT" "$REF_PRIV_FILTER"
     pcap_filter public  "$REF_PUB_OUTPUT"  "$PUBOUTPUT"  "$REF_PUB_FILTER"
 
-    if [ -n "$REF_CONSOLE_OUTPUT" ]
-    then
-	consolediff "" OUTPUT${KLIPS_MODULE}/console.txt $REF_CONSOLE_OUTPUT
-    fi
+    case $KERNVER in
+	26) if [ -n "$REF26_CONSOLE_OUTPUT" ]
+	    then
+		consolediff "26" OUTPUT${KLIPS_MODULE}/console.txt $REF26_CONSOLE_OUTPUT
+	    fi;;
+	*) if [ -n "$REF_CONSOLE_OUTPUT" ]
+	   then
+	        consolediff "" OUTPUT${KLIPS_MODULE}/console.txt $REF_CONSOLE_OUTPUT
+           fi;;
+    esac
 
     case "$success" in
     true)	exit 0 ;;
@@ -881,6 +887,105 @@ rpm_build_install_test() {
     recordresults $testdir "$testexpect" "$stat" $testdir${KLIPS_MODULE}
 }
 
+###################################
+#
+#  test type: ipkg_build_install_test
+#
+###################################
+
+
+do_ipkg_install_test() {
+
+    rm -rf OUTPUT${KLIPS_MODULE}/root
+    mkdir -p OUTPUT${KLIPS_MODULE}/root
+
+    success=true
+    instdir=`cd OUTPUT${KLIPS_MODULE}/root && pwd`
+
+    prerunsetup
+
+    KERNEL_SOURCE=`eval echo $KERNEL_SOURCE`
+    if [ -z "$KERNEL_SOURCE" ]
+    then
+	echo "Test must define \$KERNEL_SOURCE ($KERNEL_SOURCE)"
+	success='missing $KERNEL_SOURCE'
+	exit 99
+    fi
+
+    if [ -z "$OMIT_BUILD" ]
+    then
+	echo "Building with kernel source $KERNEL_SOURCE";
+
+	(cd $OPENSWANSRCDIR && make clean --no-print-directory && make --no-print-directory KERNELSRC=$KERNEL_SOURCE OPENSWANSRCDIR=$OPENSWANSRCDIR DESTDIR=/tmp/ipkg ipkg )
+    fi
+
+    mkdir OUTPUT${KLIPS_MODULE}/ipkg
+    cp $OPENSWANSRCDIR/packaging/ipkg/ipkg/*.ipk  OUTPUT${KLIPS_MODULE}/ipkg
+
+    # while loop below winds up in sub-shell. Argh.
+    successfile=OUTPUT${KLIPS_MODULE}/success
+    echo "$success" >$successfile
+
+    if [ -n "$REF_IPKG_CONTENTS" ]
+    then
+      cat $REF_IPKG_CONTENTS | while read ipkgfile ipkgcontents
+      do
+        if [ -z "$ipkgfile" ]
+	then
+	    continue;
+	fi
+        # expand $ipkgfile, which may have wildcards!
+	realfile=`eval echo OUTPUT${KLIPS_MODULE}/ipkg/${ipkgfile}`
+	if [ ! -f $realfile ]
+	then
+	    echo "IPKG production failed to build anything to match $ipkgfile"
+	    echo false >$successfile
+	fi
+        tar -tzvf  $realfile >OUTPUT${KLIPS_MODULE}/$ipkgcontents.txt
+	if diff -u -w -b -B $ipkgcontents.txt OUTPUT${KLIPS_MODULE}/$ipkgcontents.txt >OUTPUT${KLIPS_MODULE}/$ipkgcontents.diff
+	then
+	    echo "Reffile ($ipkgcontents) for $realfile matched"
+	else
+	    echo "Reffile ($ipkgcontents) for $realfile differed"
+	    echo false >$successfile
+	fi
+      done
+    fi
+
+    success=`cat $successfile`
+
+    case "$success" in
+    true)	exit 0 ;;
+    *)		exit 1 ;;
+    esac
+}
+
+
+
+# test entry point:
+ipkg_build_install_test() {
+    testdir=$1
+    testexpect=$2
+
+    echo '**** Make Install RUNNING' $testdir${KLIPS_MODULE} '****'
+
+    OPENSWANSRCDIR=`cd $OPENSWANSRCDIR && pwd` export OPENSWANSRCDIR
+
+    export UML_BRAND="$$"
+    ( preptest $testdir ipkg_build_install_test && do_ipkg_install_test )
+    stat=$?
+    if [ $stat = 99 ]
+    then
+        echo Test missing parts.
+	stat='missing parts'
+    fi
+
+    recordresults $testdir "$testexpect" "$stat" $testdir${KLIPS_MODULE}
+}
+
+
+
+
 ###################################
 #
 #  test type: libtest
@@ -899,7 +1004,10 @@ libtest() {
 
     symbol=`echo $testobj | tr 'a-z' 'A-Z'`_MAIN
 
-    if [ -f ${LIBOPENSWANDIR}/$testsrc ] 
+    if [ -f ./$testsrc ] 
+    then
+	FILE=./$testsrc
+    elif [ -f ${OPENSWANSRCDIR}/lib/libopenwan/$testsrc ]
     then
 	FILE=${LIBOPENSWANDIR}/$testsrc
     elif [ -f ${OPENSWANSRCDIR}/lib/libopenwan/$testsrc ]
@@ -919,22 +1027,44 @@ libtest() {
         FILE=${OPENSWANSRCDIR}/linux/net/ipsec/$testsrc
     fi
 
+    #echo "LOOKING for " ./FLAGS.$testobj
+
+    EXTRAFLAGS=
+    EXTRALIBS=
+    if [ -f ./FLAGS.$testobj ]
+    then
+	source ./FLAGS.$testobj
+    fi
+
     stat=99
     if [ -n "$FILE" -a -r "$FILE" ]
     then
-	    ${CC} -g -o $testobj -D$symbol -I${LIBOPENSWANDIR} -I${OPENSWANSRCDIR}/linux/include -I${OPENSWANSRCDIR} ${FILE} ${OPENSWANLIB}
+	    echo CC: ${CC} -g -o $testobj -D$symbol ${EXTRAFLAGS} -I${LIBOPENSWANDIR} -I${OPENSWANSRCDIR}/linux/include -I${OPENSWANSRCDIR} ${FILE} ${OPENSWANLIB} ${EXTRALIBS}
+	    ${CC} -g -o $testobj -D$symbol ${EXTRAFLAGS} -I${LIBOPENSWANDIR} -I${OPENSWANSRCDIR}/linux/include -I${OPENSWANSRCDIR} ${FILE} ${OPENSWANLIB} ${EXTRALIBS}
 	    rm -rf lib-$testobj/OUTPUT
 	    mkdir -p lib-$testobj/OUTPUT
 
 	    export TEST_PURPOSE=regress
 
-	    ( ./$testobj -r >lib-$testobj/OUTPUT${KLIPS_MODULE}/$testobj.txt )
+	    echo Running $testobj
+	    ( ulimit -c unlimited; cd lib-$testobj && ../$testobj -r >OUTPUT${KLIPS_MODULE}/$testobj.txt 2>&1 )
 
 	    stat=$?
+	    echo Exit code $stat
 	    if [ $stat -gt 128 ]
 	    then
 		stat="$stat core"
-	    fi
+	    else
+		if [ -r OUTPUT.$testobj.txt ]
+		then
+		    if diff -N -u -w -b -B lib-$testobj/OUTPUT${KLIPS_MODULE}/$testobj.txt OUTPUT.$testobj.txt > lib-$testobj/OUTPUT${KLIPS_MODULE}/$testobj.output.diff
+		    then
+			echo "output matched"
+		    else
+			echo "output differed"
+		    fi
+		fi
+            fi
     fi
 
     TEST_PURPOSE=regress  UML_BRAND=0 recordresults lib-$testobj "$testexpect" $stat lib-$testobj
@@ -1106,7 +1236,7 @@ do_module_compile_test() {
 
     kernel_var_name=KERNEL_${kernelname}${kernelver}_SRC
     echo Looking for kernel source ${kernel_var_name}
-    KERNEL_SRC=${!kernel_var_name}
+    KERNEL_SRC=${!kernel_var_name}${KERNVER}
 
     if [ -z "${KERNEL_SRC}" ]
     then
@@ -1181,12 +1311,16 @@ do_module_compile_test() {
 
     rm -f OUTPUT${KLIPS_MODULE}/module/ipsec.o
 
-    cmd="(cd $OPENSWANSRCDIR && make KERNELSRC=$KERNEL_SRC MODBUILDDIR=$moddir OPENSWANSRCDIR=$OPENSWANSRCDIR MODULE_DEFCONFIG=${MODULE_DEFCONFIG} MODULE_DEF_INCLUDE=${MODULE_DEF_INCLUDE} ARCH=${ARCH} SUBARCH=${SUBARCH} module )"
+    cmd="(cd $OPENSWANSRCDIR && make KERNELSRC=$KERNEL_SRC MOD${KERNVER}BUILDDIR=$moddir OPENSWANSRCDIR=$OPENSWANSRCDIR MODULE_DEFCONFIG=${MODULE_DEFCONFIG} MODULE_DEF_INCLUDE=${MODULE_DEF_INCLUDE} ARCH=${ARCH} SUBARCH=${SUBARCH} module${KERNVER} )"
     echo "# run as" >OUTPUT${KLIPS_MODULE}/doit.sh
     echo "$cmd" >>OUTPUT${KLIPS_MODULE}/doit.sh
     . OUTPUT${KLIPS_MODULE}/doit.sh
 
-    if [ -r OUTPUT${KLIPS_MODULE}/module/ipsec.o ]
+    if [ -n "${KERNEL_PROCESS_FILE}" ]
+    then
+      source ${KERNEL_PROCESS_FILE} 
+
+    elif [ -r OUTPUT${KLIPS_MODULE}/module/ipsec.o ]
     then
 	success=true
     fi
@@ -1293,8 +1427,8 @@ do_umlX_test() {
        fi
        export ${host}_START
 
-       eval "REF_${host}_CONSOLE_RAW=OUTPUT${KLIPS_MODULE}/${lhost}console.txt"
-       export REF_${host}_CONSOLE_RAW
+       eval "REF${KERNVER}_${host}_CONSOLE_RAW=OUTPUT${KLIPS_MODULE}/${KERNVER}${lhost}console.txt"
+       export REF${KERNVER}_${host}_CONSOLE_RAW
        export ${host}_INIT_SCRIPT
        export ${host}_RUN_SCRIPT
        export ${host}_RUN2_SCRIPT
@@ -1311,7 +1445,6 @@ do_umlX_test() {
 	export ${net}_ARPREPLY
     done
 
-
     if [ -n "$REF_EAST_OUTPUT" ]
     then
 	EASTOUTPUT=`basename $REF_EAST_OUTPUT .txt `
@@ -1369,12 +1502,12 @@ do_umlX_test() {
     for host in $XHOST_LIST
     do
        local consoleref
-       consoleref=REF_${host}_CONSOLE_OUTPUT
+       consoleref=REF${KERNVER}_${host}_CONSOLE_OUTPUT
        lhost=`echo $host | tr 'A-Z' 'a-z'`
 
 	if [ -n "${!consoleref}" ]
 	then
-	    consolediff $lhost OUTPUT${KLIPS_MODULE}/${lhost}console.txt ${!consoleref}
+	    consolediff ${KERNVER}$lhost OUTPUT${KLIPS_MODULE}/${KERNVER}${lhost}console.txt ${!consoleref}
 	fi
     done
 
@@ -1400,9 +1533,40 @@ umlXhost() {
 }
 
 #
-# $Id: functions.sh,v 1.108 2004/05/19 14:53:31 mcr Exp $
+# $Id: functions.sh,v 1.117 2004/11/09 18:36:35 ken Exp $
 #
 # $Log: functions.sh,v $
+# Revision 1.117  2004/11/09 18:36:35  ken
+# rpm -> ipkg
+#
+# Revision 1.116  2004/11/09 18:30:24  ken
+# Add functions for ipkg_build_install_test
+#
+# Revision 1.115  2004/10/20 01:43:58  mcr
+# 	redirected stderr to capture file as well.
+#
+# Revision 1.114  2004/10/19 22:10:54  mcr
+# 	capture and compare the output as well.
+#
+# Revision 1.113  2004/10/17 17:37:45  mcr
+# 	run library tests in the subdir (so core will go there),
+# 	and make sure that core dumps are enabled.
+#
+# Revision 1.112  2004/10/16 22:53:22  mcr
+# 	added EXTRAFLAGS and EXTRALIBS variable to library test
+# 	process, and provide FLAGS.testobj file to configure
+# 	test case.
+#
+# Revision 1.111  2004/09/21 01:20:09  mcr
+# 	support per-kernel console output
+#
+# Revision 1.110  2004/09/13 02:26:48  mcr
+# 	use appropriate console comparison file.
+#
+# Revision 1.109  2004/08/22 04:59:59  mcr
+# 	fix up module compile test to work with 2.6.
+# 	added post-build complicated check.
+#
 # Revision 1.108  2004/05/19 14:53:31  mcr
 # 	call summarize results just before each test case.
 #
