@@ -1,4 +1,4 @@
-# $Id: netjig.tcl,v 1.48 2004/05/05 17:55:20 mcr Exp $
+# $Id: netjig.tcl,v 1.49 2004/10/12 03:51:47 mcr Exp $
 
 global theprompt
 set theprompt {([a-zA-Z0-9]*):.*# }
@@ -272,6 +272,10 @@ proc inituml {umlname} {
 
     send -i $umlid($umlname,spawnid) -- "exec bash --noediting\r"
 
+    expectprompt $umlid($umlname,spawnid) "for ulimit ($umlname)"
+
+    send -i $umlid($umlname,spawnid) -- "ulimit -c unlimited\r"
+
     if {[info exists env(KLIPS_MODULE)]} {
 	puts stderr "Loading module into $umlname"
 
@@ -539,9 +543,12 @@ proc process_net {net} {
 
 match_max -d 10000
 
-# $Id: netjig.tcl,v 1.48 2004/05/05 17:55:20 mcr Exp $
+# $Id: netjig.tcl,v 1.49 2004/10/12 03:51:47 mcr Exp $
 #
 # $Log: netjig.tcl,v $
+# Revision 1.49  2004/10/12 03:51:47  mcr
+# 	make sure that UMLs run with core dumping enabled.
+#
 # Revision 1.48  2004/05/05 17:55:20  mcr
 # 	fixed problem with getty not licking multiuser boot.
 #
