@@ -356,7 +356,7 @@ if($subtotal > 0) {
 }
 
 print HTMLFILE "</TABLE>  \n";
-print HTMLFILE "\n<BR><PRE>TOTAL tests: $subtotal ($skipped skipped)  PASSED: $passed   FAILED: $failed   MISSED: $missed  SUCCESS RATE: $testrate%</PRE><BR>\n";
+print HTMLFILE "\n<BR><PRE>TOTAL tests: $total SKIPPED: $skipped   PASSED: $passed   FAILED: $failed   MISSED: $missed  SUCCESS RATE: $testrate%</PRE><BR>\n";
 print HTMLFILE "<A HREF=\"stdout.txt\">stdout</A><BR>\n";
 print HTMLFILE "<A HREF=\"stderr.txt\">stderr</A><BR>\n";
 print HTMLFILE "</BODY></HTML>\n";
